@@ -7,13 +7,13 @@ import os
 try:
     from setuptools import setup, find_packages
 except ImportError as ie:
-    import ez_setup
-    ez_setup.use_setuptools()
+    import distribute_setup
+    distribute_setup.use_setuptools()
     from setuptools import setup, find_packages
 
 # Startup
 appname = "python-graph-dot"
-appversion = "1.8.0"
+appversion = "1.8.1"
 
 setup(
         name = appname,
